#
# spec file for package deepin-kwin
#
# Copyright (c) 2021 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2021 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define   _name           dde-kwin
%define   sover           0
%define   kwin_version    %(rpm -q --queryformat '%%{VERSION}' kwin5)
%define   kwin_max        5.25.1

Name:           deepin-kwin
Version:        5.4.26
Release:        bp154.2.3.1
Summary:        KWin configures/plugins on the DDE
License:        GPL-3.0-or-later
Group:          System/GUI/Other
Url:            https://github.com/linuxdeepin/dde-kwin
Source0:        https://github.com/linuxdeepin/dde-kwin/archive/%{version}/%{_name}-%{version}.tar.gz
Patch0:         %{name}-tabbox-chameleon-rename.patch
Patch1:         fix-build-on-5_18_6.patch
Patch2:         dde-kwin.5.4.26.patch
# PATCH-FIX-UPSTRAM fix-library-links.patch hillwood@opensuse.org - Fix build on Tumbleweed
# https://github.com/linuxdeepin/dde-kwin/pull/154
Patch3:         fix-library-links.patch
Patch4:         drop-nonexistent-translations.patch
BuildRequires:  fdupes
BuildRequires:  gtest
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5XmlPatterns)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(dtkcore)
BuildRequires:  pkgconfig(dtkgui) >= 5.0.0
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(gsettings-qt)
BuildRequires:  cmake(KF5GlobalAccel)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  kwin5-devel
BuildRequires:  libepoxy-devel
BuildRequires:  plasma5-workspace-devel
BuildRequires:  libQt5Gui-private-headers-devel 
BuildRequires:  libQt5Core-private-headers-devel
BuildRequires:  libQt5PlatformSupport-devel-static
Requires:       deepin-wallpapers
Requires:       dbus-1
Requires:       kwin5
Provides:       deepin-kwin5

%description
KWin configures/plugins on the DDE
Let kwin work well in the Deepin Desktop Environment.

# %if "%{kwin_version}" <= "%{kwin_max}"
%package -n libkwin-xcb%{sover}
Summary:        Deepin Kwin libraries
Group:          System/Libraries

%description -n libkwin-xcb%{sover}
KWin configures/plugins on the DDE
Let kwin work well in the Deepin Desktop Environment.

%package devel
Summary:        Development tools for deepin-plugin-kwin
Group:          Development/Libraries/C and C++
Requires:       libkwin-xcb%{sover}

%description devel
The deepin-plugin-kwin-devel package contains the header files and developer
docs for deepin-plugin-kwin.

%lang_package
# %endif

%prep
%autosetup -p1 -n %{_name}-%{version}
sed -i 's|backgrounds/default_background.jpg|wallpapers/openSUSEdefault/contents/images/1920x1080.jpg|g' \
deepin-wm-dbus/deepinwmfaker.cpp plugins/kwineffects/multitasking/background.cpp
sed -i 's/lrelease/lrelease-qt5/g' plugins/platforms/plugin/translate_generation.sh
sed -i 's|/usr/lib|%{_libdir}|g' plugins/platforms/plugin/{main.cpp,main_wayland.cpp}

%if "%{kwin_version}" > "%{kwin_max}"
# Workaround issue#3246 (https://github.com/linuxdeepin/developer-center/issues/3246)
sed -i 's|GLRenderTarget|GLFramebuffer|g' plugins/kwineffects/scissor-window/scissorwindow.cpp
sed -i '/(!w->isPaintingEnabled() || (mask & PAINT_WINDOW_LANCZOS)/,+2d' plugins/kwineffects/scissor-window/scissorwindow.cpp
sed -i '/add_subdirectory(kdecoration)/d' plugins/CMakeLists.txt
%endif



%build
mkdir build
cd build
cmake .. -DCMAKE_INSTALL_PREFIX=%{_prefix} \
         -DCMAKE_INSTALL_LIBDIR=%{_libdir} \
         -DUSE_WINDOW_TOOL=OFF \
         -DENABLE_BUILTIN_BLUR=OFF \
         -DENABLE_KDECORATION=ON \
         -DENABLE_BUILTIN_MULTITASKING=OFF \
         -DENABLE_BUILTIN_BLACK_SCREEN=OFF \
%if "%{kwin_version}" > "%{kwin_max}"
         -DENABLE_BUILTIN_SCISSOR_WINDOW=OFF \
%endif
         -DUSE_DEEPIN_WAYLAND=OFF
%cmake_build

%install
%cmake_install

rm -rf %{buildroot}%{_datadir}/kwin/*/*/LICENSE

rm -rf \
    %{buildroot}%{_sysconfdir}/xdg/kwinrc \
    %{buildroot}%{_sysconfdir}/xdg/kdeglobals

%fdupes %{buildroot}

%post -n libkwin-xcb%{sover} -p /sbin/ldconfig

%postun -n libkwin-xcb%{sover} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc CHANGELOG.md
%license LICENSE
%config %{_sysconfdir}/xdg/*
%{_bindir}/kwin_no_scale
%dir %{_datadir}/kwin
%dir %{_datadir}/kwin/scripts
%dir %{_datadir}/kwin/tabbox
%{_datadir}/kwin/scripts/*
%{_datadir}/kwin/tabbox/*
%{_bindir}/deepin-wm-dbus
%{_datadir}/dbus-1/interfaces/*.xml
%{_datadir}/dbus-1/services/com.deepin.wm.service
%{_kf5_plugindir}/platforms/libdde-kwin-xcb.so
%if "%{kwin_version}" <= "%{kwin_max}"
%{_kf5_plugindir}/org.kde.kdecoration2/libdeepin-chameleon.so
%dir %{_kf5_plugindir}/kwin/effects/plugins/
#%{_kf5_plugindir}/kwin/effects/plugins/libblur.so
# %{_kf5_plugindir}/kwin/effects/plugins/libmultitasking.so
%{_kf5_plugindir}/kwin/effects/plugins/libscissor-window.so
%endif
%{_kf5_plugindir}/platforms/libdde-kwin-wayland.so

%files -n libkwin-xcb%{sover}
%defattr(-,root,root,-)
%{_libdir}/libkwin-xcb.so.*

%files lang
%defattr(-,root,root,-)
%{_datadir}/dde-kwin-xcb

%files devel
%defattr(-,root,root,-)
%{_libdir}/libkwin-xcb.so
%{_includedir}/%{_name}
%{_libdir}/pkgconfig/dde-kwin.pc
%changelog
* Fri Jun 10 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version 5.4.26
  * update window raduis for effects
  * Add splitmenu translate
  * Add a dependency on 'kwin-wayland'
  * Add func about maxi button long press
  * Modify code based on code review results
  * Fix bugs
- Add dde-kwin.5.4.26.patch, fix build on kwin 5.24+
- Add drop-nonexistent-translations.patch
- No longer need kwayland-server (boo#1200318)
- Drop deepin-kwin-crash.patch
* Sat Feb 26 2022 Max Lin <mlin@suse.com>
- Fix Leap 15.4 build since Kwin has greater version than 5.21
  in Leap 15.4
* Fri Feb 25 2022 Hillwood Yang <hillwood@opensuse.org>
- Add fix-build-on-5_18_6.patch for leap
* Sun Feb 20 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version 5.4.19
  * Frees heap memory when the program exits
  * Disable multitasking
  * disable effects by default
  * Support DDE Wayland
  * Support client activation from dde shell
  * Fix bugs
* Tue Nov 30 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.12
  * Split screen mode is always grayed out in the working area
  * add split screen menu
  * support lightWeight config for shadow
  * optimize work thumbnail
  * Fix bugs
  * Workaround: builds are not performed under Kwin greater than 5.21
* Tue Nov  9 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.3.14
  * Fix bugs
  * Update translations
* Wed Sep 22 2021 Hillwood Yang <hillwood@opensuse.org>
- Add fix-library-links.patch, fix build on Tumbleweed
* Tue Jun 15 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.3.9
  * Fix bugs
  * Support kwin 5.21+, drop support-kwin-5_21+.patch
- Drop fix-crash-bug.patch, fixed by upstream
* Tue May  4 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.3.7
  * Support kwin 5.19, drop support-kwin-5_19+.patch
  * Add translation files
  * update dde-kwin.postinst base on update DTK's /etc/os-version
  * Fix bugs
- Drop deepin-kwin-unload-blur.patch, merged by upstream
* Sun Apr 11 2021 Hillwood Yang <hillwood@opensuse.org>
- Support kwin 5.21+, add support-kwin-5_19+.patch and
  support-kwin-5_21+.patch
* Mon Mar  1 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.2.0.13
  * fix: Avoid taskbar showing up when changing workspace in multitaskingview
  * Revert "fix: Provides a default wallpaper for the second workspace."
  * fix: mips platform second workspace background is white.
  * Provides a default wallpaper for the second workspace.
  * fix get sp1 default-uri method.
  * fix: A color field flicker when right-click menu show up
    Adjust the order of image processing
  * after system upgrading from SP1 to SP2, the old wallpaper will be kept.
  * Provides a default wallpaper for the second workspace.
  * remove dialog rule to avoid configuration by user
  * fix: Blur multitasking background.
- Add patches: deepin-kwin-crash.patch, deepin-kwin-tabbox-chameleon-rename.patch
  and deepin-kwin-unload-blur.patch
* Sat Mar 21 2020 Hillwood Yang <hillwood@opensuse.org>
- remove some files which are in plasma5-defaults-openSUSE
* Fri Jul 19 2019 Hillwood Yang <hillwood@opensuse.org>
- update version to 0.1.0
  * Allow configuration items to override the default theme
  * Add the "deepin-chameleon" window decoration for kwin
  * Support get the shoutcut default value
  * Correct the path to find translation files
  * Ignore the RuleBook::save function of kwin
  * Execute dirname before setting the LD_PRELOAD environment
  * Support KWin highlightWindows effect for PreviewWindow
  * Overwrite the window menu
  * Support for specifying the version of kwin on build
  * Multitaskingview: add multitaskingview ts
  * Automatically append the wallpaper's gsetting value item
  * Clean LD_PRELOAD env
  * Fix the window was closed incorrectly
  * Fix the "Window to Desktop" shoutcuts is invalid
  * Fix No warning when opening the multitasking view app in 2D window manager
  * Fix do not print warning messages when the build and runtime versions are consistent
  * keep window to viewable if it is minimized
  * Disable theme cache of FrameSvg
  * Install the "kdeglobals" file
  * Fix the compositingEnabledChanged signal is sent only when the user actively sets it
  * Fix the window default cursor of the gtk application does not follow the theme
  * Disable window manager window menu
  * Preview window give priority to use the dbus interface by kwin
  * Support PresentWindows
  * Support set cursor theme/size for kwin
* Wed May  8 2019 Hillwood Yang <hillwood@opensuse.org>
- Initial package for version 0.0.5
